calc_median_dayslost: Calculate the median days lost
Description
Calculate the median of the days lost due to a sports-related health problem
(e.g. disease, injury).
Usage
calc_median_dayslost(injd, by = NULL, overall = TRUE)
Value
The median of the days lost. Either a numeric value (if overall
TRUE) or a data frame indicating the median days lost per athlete.
Arguments
injd
injdS3 object (see
prepare_all()).
by
Character specifying the name of the column according to which
compute summary statistics. It should refer to a (categorical) variable
that describes a grouping factor (e.g. "type of case or injury", "injury
location", "sports club"). Optional, defaults to NULL.
overall
Logical, whether to calculate overall (for all the cohort) or
athlete-wise summary statistic (i.e. number of cases per cohort of per
athlete). Defaults to TRUE.