Learn R Programming

injurytools (version 2.0.1)

calc_ncases: Calculate number of cases

Description

Calculate the number of sports-related cases (e.g. injuries) that occurred in a cohort during a period.

Usage

calc_ncases(injd, by = NULL, overall = TRUE)

Value

The number of cases. Either a numeric value (if overall TRUE) or a data frame indicating the number of cases per athlete.

Arguments

injd

injd S3 object (see prepare_all()).

by

Character specifying the name of the column according to which compute summary statistics. It should refer to a (categorical) variable that describes a grouping factor (e.g. "type of case or injury", "injury location", "sports club"). Optional, defaults to NULL.

overall

Logical, whether to calculate overall (for all the cohort) or athlete-wise summary statistic (i.e. number of cases per cohort of per athlete). Defaults to TRUE.

Examples

Run this code
calc_ncases(injd)
calc_ncases(injd, overall = FALSE)
calc_ncases(injd, by = "injury_type")

Run the code above in your browser using DataLab