Learn R Programming

injurytools (version 2.0.1)

check_injfollowup: Check the dates in injury data and exposure data

Description

Check that dates of injury data are within the dates of exposure data.

Usage

check_injfollowup(followup_df, data_injuries)

Value

Same injury data or cut injury data in which the dates of injury occurrences are within the dates of each person_id's follow-up period.

Arguments

followup_df

Data frame created inside prepare_all() function.

data_injuries

Data frame given in prepare_all() function.