Calculate the case burden rate of a sports-related health problem (e.g. disease, injury) in a cohort.
calc_burden(
injd,
by = NULL,
overall = TRUE,
method = c("poisson", "negbin", "zinfpois", "zinfnb"),
se = TRUE,
conf_level = 0.95,
scale = TRUE,
quiet = FALSE
)The case burden rate. Either a numeric value (if overall
TRUE) or a data frame indicating the case burden rate per
athlete.
injd S3 object (see
prepare_all()).
Character specifying the name of the column according to which
compute summary statistics. It should refer to a (categorical) variable
that describes a grouping factor (e.g. "type of case or injury", "injury
location", "sports club"). Optional, defaults to NULL.
Logical, whether to calculate overall (for all the cohort) or
athlete-wise summary statistic (i.e. number of cases per cohort of per
athlete). Defaults to TRUE.
Method to estimate the incidence (burden) rate. One of "poisson", "negbin", "zinfpois" or "zinfnb"; that stand for Poisson method, negative binomial method, zero-inflated Poisson and zero-inflated negative binomial.
Logical, whether to calculate the confidence interval related to the rate.
Confidence level (defaults to 0.95).
Logical, whether to transform the incidence and burden rates
output according to the unit of exposure (defaults to TRUE).
Logical, whether or not to silence the warning messages
(defaults to FALSE).
Bahr R., Clarsen B., & Ekstrand J. (2018). Why we should focus on the burden of injuries and illnesses, not just their incidence. British Journal of Sports Medicine, 52(16), 1018–1021. tools:::Rd_expr_doi("10.1136/bjsports-2017-098160")
Waldén M., Mountjoy M., McCall A., Serner A., Massey A., Tol J. L., ... & Andersen T. E. (2023). Football-specific extension of the IOC consensus statement: methods for recording and reporting of epidemiological data on injury and illness in sport 2020. British journal of sports medicine.
calc_burden(injd)
calc_burden(injd, overall = FALSE)
calc_burden(injd, by = "injury_type")
Run the code above in your browser using DataLab