Calculate the time of exposure that each athlete, or the entire cohort of
athletes, has been at risk for a sport-related health problem.
Usage
calc_exposure(injd, by = NULL, overall = TRUE, quiet = FALSE)
Value
The total exposure time. Either a numeric value (if overall
TRUE) or a data frame indicating the total exposure time for each
athlete.
Arguments
injd
injdS3 object (see
prepare_all()).
by
Character specifying the name of the column according to which
compute summary statistics. It should refer to a (categorical) variable
that describes a grouping factor (e.g. "type of case or injury", "injury
location", "sports club"). Optional, defaults to NULL.
overall
Logical, whether to calculate overall (for all the cohort) or
athlete-wise summary statistic (i.e. number of cases per cohort of per
athlete). Defaults to TRUE.
quiet
Logical, whether or not to silence the warning messages
(defaults to FALSE).