data_injurieslong: Transform injury data into a long format
Description
Transform injury data into a long format
Usage
data_injurieslong(data_injuries)
Value
The data_injuries data frame in long format in which each row
corresponds to person-event.
Arguments
- data_injuries
Injury data frame with standardized column names, in the
same fashion that prepare_inj() returns.